@@ -1,7 +1,7 @@
 package Switch::Right;
 
 use 5.036;
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 
 use experimental qw< builtin refaliasing try >;
 use builtin      qw< true false is_bool blessed created_as_number reftype >;
@@ -831,7 +831,7 @@ Switch::Right -  Switch and smartmatch done right this time
 
 =head1 VERSION
 
-This document describes Switch::Right version 0.000003
+This document describes Switch::Right version 0.000004
 
 
 =head1 SYNOPSIS
@@ -1246,6 +1246,111 @@ Under this module, two references only smartmatch if:
 =back
 
 
+=head4 Boolean arguments are handled differently
+
+Since Perl v5.36, the language has offered L<distinguished true and false values|builtin#true>
+that can be detected at runtime using the L<C<is_bool() builtin|builtin#is_bool>.
+All boolean operators and some built-in functions (such as C<exists()> and C<defined()>)
+return these special values, which can then be identified as originating from a boolean expression.
+
+The former C<~~> operator had no special behaviour when passed such values,
+but C<smartmatch()> does. When a distinguished boolean value is passed as the
+right-hand argument, C<smartmatch()> simply returns that value as the result of the match.
+Hence:
+
+    smartmatch( $anything, $count == 1 )          # returns true if $count is 1
+    smartmatch( $anything, exists %seen{$key} )   # returns true if key is present
+    smartmatch( $anything, !$expected)            # returns true is $expected is false
+
+This behaviour might seem odd, unintuitive, or even wrong, but it makes much more sense
+when C<smartmatch()> is used automatically to evaluate a C<when> expression:
+
+    given ($value) {
+        when ($_ == 1)              { say "value is 1"          }
+        when (exists $seen->{$_})   { say "value has been seen" }
+        when (!$_)                  { say "value is false"      }
+    }
+
+The former built-in C<when> block had L<eight special cases|https://perldoc.perl.org/5.40.0/perlsyn#Experimental-Details-on-given-and-when> where a C<when> behaved in this way
+(i.e. more like an C<if>).
+
+The module has only one special case: wherever the C<when> expression (or the
+right-hand argument of an explciit call to C<smartmatch()>) evaluates to a
+distinguished boolean. This means that you can use I<any> expression that produces
+C<builtin::true> or C<builtin::false> in a C<when> and have it act as expected:
+
+    given ($value) {
+        when (eof)                   { say "value is exhausted"         }
+        when (m/\s/)                 { say "value has a space"          }
+        when (defined)               { say "value is defined"           }
+        when (-r -w -x)              { say "value has file permissions" }
+        when (-1 < $_ < 1)           { say "value is in range"          }
+        when (looks_like_number $_)  { say "value is defined"           }
+        when (my_bool_test_func($_)) { say "value passed the test"      }
+    }
+
+Note, however, that there are many expressions which Perl can I<treat> as
+boolean, but which B<do not> actually produce the distinguished boolean values
+that enable this special smartmatching behaviour.
+
+For example, the following C<when> blocks don't work as intended:
+
+    given ($value) {
+        when (ref)                  { say "value is a reference"      }  # WRONG
+        when (tell)                 { say "not at start of input"     }  # WRONG
+        when ($_ % 2)               { say "value is odd"              }  # WRONG
+        when (length)               { say "value is not empty string" }  # WRONG
+        when (keys %$_)             { say "hashref is not empty "     }  # WRONG
+        when (blessed $_)           { say "value is an object"        }  # WRONG
+        when (my_int_test_func($_)) { say "value passed the test"     }  # WRONG
+    }
+
+To ensure that a C<when> treats its argument as a direct boolean test, you need
+to make that argument is explicitly boolean:
+
+    given ($value) {
+        when (ref ne "")    { say "value is a reference"      }
+        when (tell != 0)    { say "not at start of input"     }
+        when ($_ % 2 == 1)  { say "value is odd"              }
+        when (length > 0)   { say "value is not empty string" }
+        when (keys %$_ > 0) { say "hashref is not empty "     }
+    }
+
+...or E<mdash> if the argument is a subroutine call E<mdash> that the argument
+is specified as a subref:
+
+    given ($value) {
+        when (\&blessed)          { say "value is an object"        }
+        when (\&my_int_test_func) { say "value passed the test"     }
+    }
+
+There are two other special cases to be aware of:
+
+    given ($value) {
+        when (true)  { say "the value was true"  }   # WRONG
+        when (false) { say "the value was false" }   # WRONG
+    }
+
+A C<when (true)> doesn't test whether C<$_> is C<true>.
+Instead, it is B<always> executed (like an C<if (true)>).
+Likewise, a C<when (false)> doesn't test against C<false>;
+it is simply B<never> executed (like an C<if (false)>).
+
+If you want to test for general truth or falsehood in a C<when>, you need:
+
+    given ($value) {
+        when (!! $_) { say "the value was true"  }
+        when ( ! $_) { say "the value was false" }
+    }
+
+And, if you want to test for I<distinguished> truth or falsehood in a C<when>, you need:
+
+    given ($value) {
+        when (is_bool($_) &&  $_) { say "the value was distinguished true"  }
+        when (is_bool($_) && !$_) { say "the value was distinguished false" }
+    }
+
+
 =head4 Numeric matching is stricter
 
 The former C<~~> operator attempted to match numerically whenever its right-hand argument
